@@ -1,6 +1,6 @@
 #' @rdname ggpredict
 #' @export
-ggeffect <- function(model, terms, ci.lvl = 0.95, verbose = TRUE, ...) {
+ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_level, ...) {
   insight::check_if_installed("effects")
   model_name <- deparse(substitute(model))
 
@@ -14,13 +14,20 @@ ggeffect <- function(model, terms, ci.lvl = 0.95, verbose = TRUE, ...) {
     terms <- .list_to_character_terms(terms)
   }
 
+  ## TODO: add warnings later
+
+  # handle deprectated arguments
+  if (!missing(ci.lvl)) {
+    ci_level <- ci.lvl
+  }
+
   # tidymodels?
   if (inherits(model, "model_fit")) {
     model <- model$fit
   }
 
   if (inherits(model, "list")  && !inherits(model, c("bamlss", "maxLik"))) {
-    res <- lapply(model, .ggeffect_helper, terms, ci.lvl, verbose, ...)
+    res <- lapply(model, .ggeffect_helper, terms, ci.lvl = ci_level, verbose, ...)
   } else {
     if (missing(terms) || is.null(terms)) {
       predictors <- insight::find_predictors(
@@ -32,7 +39,7 @@ ggeffect <- function(model, terms, ci.lvl = 0.95, verbose = TRUE, ...) {
       res <- lapply(
         predictors,
         function(.x) {
-          tmp <- .ggeffect_helper(model, terms = .x, ci.lvl, verbose, ...)
+          tmp <- .ggeffect_helper(model, terms = .x, ci.lvl = ci_level, verbose, ...)
           if (!is.null(tmp)) {
             tmp$group <- .x
           }
@@ -48,7 +55,7 @@ ggeffect <- function(model, terms, ci.lvl = 0.95, verbose = TRUE, ...) {
         res <- NULL
       }
     } else {
-      res <- .ggeffect_helper(model, terms, ci.lvl, verbose, ...)
+      res <- .ggeffect_helper(model, terms, ci.lvl = ci_level, verbose, ...)
     }
   }
 
