@@ -7,8 +7,10 @@
 #'   for representative values as in `ggpredict()`.
 #'
 #' @param model A fitted model object.
-#' @param terms Character vector with the names of those terms from
-#'   `model` for which all combinations of values should be created.
+#' @param terms Character vector with the names of those terms from `model` for
+#'   which all combinations of values should be created. This argument works in
+#'   the same way as the `terms` argument in `ggpredict()`. See also
+#'   [this vignette](https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html).
 #' @param ... Currently not used.
 #' @inheritParams ggpredict
 #'
@@ -36,6 +38,18 @@ new_data <- function(model, terms, typical = "mean", condition = NULL, ...) {
     mf <- .safe(insight::get_data(model, source = "environment"))
   }
 
+  # check if we have a grouping variable in random effects, which we need
+  # to convert to factors. This is a hidden option captured by "...", named
+  # "group_factor".
+  dots <- list(...)
+  if (!is.null(dots$group_factor)) {
+    for (g in dots$group_factor) {
+      if (g %in% colnames(mf)) {
+        mf[[g]] <- factor(mf[[g]])
+      }
+    }
+  }
+
   .data_grid(
     model = model,
     model_frame = mf,
