@@ -34,12 +34,18 @@ pool_predictions <- function(x, ...) {
   original_x <- x
 
   if (!all(vapply(x, inherits, logical(1), "ggeffects"))) {
-    insight::format_error("'x' must be a list of 'ggeffects' objects, as returned by 'ggpredict()', 'ggemmeans()' or 'ggeffect()'.")
+    insight::format_error(
+      "`x` must be a list of `ggeffects` objects, as returned by `ggpredict()`, `ggemmeans()` or `ggeffect()`."
+    )
   }
 
   # check if all x-levels are identical
   if (!all(apply(as.data.frame(sapply(x, function(i) i$x), simplify = TRUE), 1, function(j) length(unique(j)) == 1))) {
-    insight::format_error(paste0("Cannot pool predictions. The values of the focal term '", attributes(x[[1]])$terms, "' are not identical across predictions."))
+    insight::format_error(paste0(
+      "Cannot pool predictions. The values of the focal term '",
+      attributes(x[[1]])$terms,
+      "' are not identical across predictions."
+    ))
   }
 
   # preparation ----
@@ -75,13 +81,13 @@ pool_predictions <- function(x, ...) {
       } else {
         link_fun(j$predicted[i])
       }
-    }))
+    }), use.names = FALSE)
     pooled_predictions$predicted[i] <- mean(pooled_pred, na.rm = TRUE)
 
     # pooled standard error
     pooled_se <- unlist(lapply(original_x, function(j) {
       j$std.error[i]
-    }))
+    }), use.names = FALSE)
     ubar <- mean(pooled_se^2, na.rm = TRUE)
     tmp <- ubar + (1 + 1 / len) * stats::var(pooled_pred)
     pooled_predictions$std.error[i] <- sqrt(tmp)
