@@ -1,13 +1,13 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("lme4") &&
-  require("sjlabelled")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("lme4") &&
+  requiet("sjlabelled")
 )) {
-  data(efc)
+  data(efc, package = "ggeffects")
 
-  efc$e15relat <- as_label(efc$e15relat)
-  efc$e42dep <- as_label(efc$e42dep)
+  efc$e15relat <- sjlabelled::as_label(efc$e15relat)
+  efc$e42dep <- sjlabelled::as_label(efc$e42dep)
   efc$c172code <- as.factor(efc$c172code)
 
   m <- lmer(neg_c_7 ~ e42dep + c172code + c12hour + c82cop1 + (1 | e15relat), data = efc)
