@@ -5,9 +5,10 @@ if (suppressWarnings(
   requiet("rms")
 )) {
 
-  data(efc)
+  data(efc, package = "ggeffects")
   efc$neg_c_7d <- dicho(efc$neg_c_7)
-  m1 <- lrm(neg_c_7d ~ c12hour + e42dep + c161sex + c172code, data = efc)
+  d <<- efc
+  m1 <- lrm(neg_c_7d ~ c12hour + e42dep + c161sex + c172code, data = d)
 
   test_that("ggpredict, lrm", {
     pr <- ggpredict(m1, "c12hour")
